@@ -1,17 +1,11 @@
 from django.contrib import admin
 from django.utils.translation import ugettext_lazy as _
 from imagekit.admin import AdminThumbnail
-from feincms.admin import editor
 
 from galeria.forms import AlbumAdminForm
 from galeria.models import Album, Picture
 
 
-# Hack to easier translate some strings from FeinCMS
-OPEN_TREE_STR = _('Expand tree')
-COLLAPSE_TREE_STR = _('Collapse tree')
-
-
 class PictureAdmin(admin.ModelAdmin):
     list_display = ('thumbnail', 'title', 'is_public', 'album', 'date_added')
     list_display_links = ('title',)
@@ -35,7 +29,7 @@ class InlinePictureAdmin(admin.TabularInline):
     model = Picture
     prepopulated_fields = {'slug': ('title',)}
 
-class AlbumAdmin(editor.TreeEditor):
+class AlbumAdmin(admin.ModelAdmin):
     form = AlbumAdminForm
     inlines = [InlinePictureAdmin]
     list_display = ('title', 'album_cover', 'is_public', 'order')
